"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _plugin = require("@parcel/plugin");

var _sourceMap = _interopRequireDefault(require("@parcel/source-map"));

var _generator = _interopRequireDefault(require("@babel/generator"));

var _semver = _interopRequireDefault(require("semver"));

var _babel = _interopRequireDefault(require("./babel6"));

var _babel2 = _interopRequireDefault(require("./babel7"));

var _config = _interopRequireDefault(require("./config"));

var _utils = require("@parcel/utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var _default = new _plugin.Transformer({
  async getConfig({
    asset
  }) {
    return (0, _config.default)(asset);
  },

  canReuseAST({
    ast
  }) {
    return ast.type === 'babel' && _semver.default.satisfies(ast.version, '^7.0.0');
  },

  async transform({
    asset,
    config
  }) {
    if (config) {
      if (config[6]) {
        asset.ast = await (0, _babel.default)(asset, config[6]);
      }

      if (config[7]) {
        asset.ast = await (0, _babel2.default)(asset, config[7]);
      }
    }

    return [asset];
  },

  async generate({
    asset,
    options
  }) {
    let sourceFileName = (0, _utils.relativeUrl)(options.projectRoot, asset.filePath); // $FlowFixMe: figure out how to make AST required in generate method

    let generated = (0, _generator.default)(asset.ast.program, {
      sourceMaps: options.sourceMaps,
      sourceFileName: sourceFileName
    });
    return {
      code: generated.code,
      map: new _sourceMap.default(generated.rawMappings, {
        [sourceFileName]: null
      })
    };
  }

});

exports.default = _default;